@@ -154,9 +154,7 @@ def test_snapshot_matches_runtime(snapshot, biskotaki_ci_project, test_root):
     )
 
     if RUNNING_ON_CI:  # quickly do sanity check
-        assert all(
-            [line_pair[0] == line_pair[1] for line_pair in line_pairs_generator]
-        ), (
+        assert all([line_pair[0] == line_pair[1] for line_pair in line_pairs_generator]), (
             f"File: CHANGELOG.rst has different content at Runtime vs Snapshot\n"
             "-------------------\n"
             f"Runtime: {runtime_changelog}\n"
@@ -197,9 +195,7 @@ def test_snapshot_matches_runtime(snapshot, biskotaki_ci_project, test_root):
         ]
     )
     if RUNNING_ON_CI:  # quickly do sanity check
-        assert all(
-            [line_pair[0] == line_pair[1] for line_pair in line_pairs_generator]
-        ), (
+        assert all([line_pair[0] == line_pair[1] for line_pair in line_pairs_generator]), (
             f"File: docs/conf.py has different content at Runtime vs Snapshot\n"
             "-------------------\n"
             f"Runtime: {runtime_conf}\n"
