@@ -56,20 +56,19 @@ def create_context_from_emulated_project(dat):
         mkdir(package_dir)
         mkdir(tests_dir)
 
-        # Emulate Docs Builder related files (ie mkdocs and sphinx)
-        mkdir(path.join(project_dir, 'docs-mkdocs'))
-        mkdir(path.join(project_dir, 'docs-mkdocs', 'dev_guides'))
-        Path(path.join(project_dir, 'docs-mkdocs', 'dev_guides', 'docker.md')).touch()
-
+        # Emulate mkdocs Docs Builder related files (as if selected by user)
+        mkdir(path.join(project_dir, 'docs'))
+        mkdir(path.join(project_dir, 'docs', 'dev_guides'))
+        Path(path.join(project_dir, 'docs', 'dev_guides', 'docker.md')).touch()
         # Path(path.join(project_dir, 'mkdocs.yml')).touch()
 
-        mkdir(path.join(project_dir, 'docs-sphinx'))
-        Path(path.join(project_dir, 'docs-sphinx', 'conf.py')).touch()
+        # Emulate sphinx Docs Builder related files for sphinx
+        TO_DELETE = 'PyGen_TO_DELETE'
+        mkdir(path.join(project_dir, TO_DELETE))
+        Path(path.join(project_dir, TO_DELETE, 'conf.py')).touch()
         # create at least one level of nest to make cover more post_removal code
-        mkdir(path.join(project_dir, 'docs-sphinx', 'contents'))
-        Path(
-            path.join(project_dir, 'docs-sphinx', 'contents', '10_introduction.rst')
-        ).touch()
+        mkdir(path.join(project_dir, TO_DELETE, 'contents'))
+        Path(path.join(project_dir, TO_DELETE, 'contents', '10_introduction.rst')).touch()
 
         mkdir(path.join(project_dir, 'scripts'))
         # Path(path.join(project_dir, 'scripts', 'gen_api_refs_pages.py')).touch()
@@ -217,9 +216,7 @@ def get_post_gen_main(get_object):
         add_cli: bool,
         project_dir: Path,
         extra_files: t.Optional[t.List[t.Union[str, t.Tuple[str, ...]]]] = None,
-        extra_non_empty_files: t.Optional[
-            t.List[t.Union[str, t.Tuple[str, ...]]]
-        ] = None,
+        extra_non_empty_files: t.Optional[t.List[t.Union[str, t.Tuple[str, ...]]]] = None,
         **kwargs,
     ):
         """"""
@@ -326,9 +323,7 @@ def test_main(
     from pathlib import Path
 
     # GIVEN a temporary directory, for the emulated generated project
-    tmp_target_gen_dir = tmpdir.mkdir(
-        'cookiecutter_python.unit-tests.proj-targetr-gen-dir'
-    )
+    tmp_target_gen_dir = tmpdir.mkdir('cookiecutter_python.unit-tests.proj-targetr-gen-dir')
 
     post_hook_main = get_post_gen_main(
         create_context_from_emulated_project,
@@ -419,9 +414,7 @@ def test_stable_cicd_was_selected_and_worked(
     from pathlib import Path
 
     # GIVEN a temporary directory, for the emulated generated project
-    tmp_target_gen_dir = tmpdir.mkdir(
-        'cookiecutter_python.unit-tests.proj-targetr-gen-dir'
-    )
+    tmp_target_gen_dir = tmpdir.mkdir('cookiecutter_python.unit-tests.proj-targetr-gen-dir')
 
     post_hook_main = get_post_gen_main(
         create_context_from_emulated_project,
@@ -441,12 +434,8 @@ def test_stable_cicd_was_selected_and_worked(
 
     # AND the files for 'experimental' cicd optoin are missing
     assert not (Path(tmp_target_gen_dir) / '.github/workflows/cicd.yml').exists()
-    assert not (
-        Path(tmp_target_gen_dir) / '.github/workflows/codecov-upload.yml'
-    ).exists()
-    assert not (
-        Path(tmp_target_gen_dir) / '.github/workflows/signal-deploy.yml'
-    ).exists()
+    assert not (Path(tmp_target_gen_dir) / '.github/workflows/codecov-upload.yml').exists()
+    assert not (Path(tmp_target_gen_dir) / '.github/workflows/signal-deploy.yml').exists()
 
 
 def test_experimental_cicd_was_selected_and_worked(
@@ -455,9 +444,7 @@ def test_experimental_cicd_was_selected_and_worked(
     from pathlib import Path
 
     # GIVEN a temporary directory, for the emulated generated project
-    tmp_target_gen_dir = tmpdir.mkdir(
-        'cookiecutter_python.unit-tests.proj-targetr-gen-dir'
-    )
+    tmp_target_gen_dir = tmpdir.mkdir('cookiecutter_python.unit-tests.proj-targetr-gen-dir')
 
     post_hook_main = get_post_gen_main(
         create_context_from_emulated_project,
