@@ -23,7 +23,11 @@ def environment():
         if sys.platform == 'win32':  # ie we are on a Windows OS
             return dict(
                 environment_variables,
-                **{'LC_ALL': 'C.UTF-8', 'LANG': 'C.UTF-8', 'PYTHONHASHSEED': '2577074909'},
+                **{
+                    'LC_ALL': 'C.UTF-8',
+                    'LANG': 'C.UTF-8',
+                    'PYTHONHASHSEED': '2577074909',
+                },
             )
         raise RuntimeError(f'Unexpected System Found: {sys.platform}')
 
